@@ -175,4 +175,4 @@ def protect_file(file_path, verbose=True):
     """
     if verbose:
         log(f"{Typgpy.WARNING}Protecting file `{file_path}` for user {user}{Typgpy.ENDC}")
-    return subprocess.check_call(["chmod", "400", file_path], env=os.environ)
+    subprocess.check_call(["chmod", "400", file_path], env=os.environ)
